@@ -1,6 +1,5 @@
 # coding=utf-8
-from ladybug_rhino.pythonpath import iron_python_search_path_windows, \
-    iron_python_search_path_mac
+from ladybug_rhino.pythonpath import iron_python_search_path_windows
 
 import os
 import io
@@ -35,21 +34,3 @@ def test_iron_python_search_path_windows_mingbo():
         set_data = fp.read()
     assert package_dir in set_data
     os.remove(edited_file)
-
-
-def test_iron_python_search_path_mac():
-    """Test the iron_python_search_path_mac method with a sample plist file."""
-    package_dir = os.path.join('ladybug_tools', 'python', 'Lib', 'site-packages')
-    setting_file = './tests/ironpython/com.mcneel.rhinoceros.plist'
-    dest_file = './tests/ironpython/new.settings.plist'
-
-    edited_file = iron_python_search_path_mac(package_dir, setting_file, dest_file)
-
-    assert os.path.isfile(edited_file)
-
-    with open(edited_file, 'rb') as fp:
-        pl = plistlib.load(fp)
-
-    sp_key = 'User.Plug-Ins.814d908a-e25c-493d-97e9-ee3861957f49.Settings.SearchPaths'
-    assert package_dir in pl[sp_key]
-    os.remove(edited_file)
